@@ -33,6 +33,7 @@ from .runners import (
     DefaultEditor,
     ImageMagick,
     RV,
+    Nuke,
     DefaultRunners,
 )
 from .site import (
@@ -411,7 +412,7 @@ class ProjectSettings(flow.Object):
         tooltip='Enable <b>upload after publish</b> by default for all files matching the provided patterns')
     hide_upload_after_publish = flow.Param('')
     clean_zip_files = flow.Child(CleanZipFiles).ui(label='Clean ZIP files')
-    enable_file_lock = flow.BoolParam(True)
+    enable_file_lock = flow.BoolParam(False)
 
     def get_auto_upload_files(self):
         return self.auto_upload.get().replace(' ', '').split(',')
@@ -529,7 +530,7 @@ class Admin(flow.Object):
     _project = flow.Parent()
 
     project_settings = flow.Child(ProjectSettings).injectable()
-    users = flow.Child(Users).ui(show_filter=True)
+    users = flow.Child(Users).ui(show_filter=True).injectable()
     multisites = flow.Child(MultisiteConfig).ui(label='Sites')
     kitsu = flow.Child(KitsuConfig)
 
@@ -557,6 +558,9 @@ class Project(flow.Object):
 
     _RUNNERS_FACTORY = None
 
+    def settings(self):
+        return self.admin.project_settings
+
     def get_root(self, alternative=None):
         '''
         alternative can be used if root_dir.get() returns None
@@ -811,6 +815,7 @@ class Project(flow.Object):
         self._RUNNERS_FACTORY.ensure_runner_type(DefaultEditor)
         self._RUNNERS_FACTORY.ensure_runner_type(ImageMagick)
         self._RUNNERS_FACTORY.ensure_runner_type(RV)
+        self._RUNNERS_FACTORY.ensure_runner_type(Nuke)
 
     def ensure_runners_loaded(self):
         session = self.root().session()
