@@ -127,6 +127,15 @@ class KitsuAPIWrapper(flow.Object):
             sequence,
             name
         )
+
+    def get_shots_data(self, sequence):
+        if isinstance(sequence, str):
+            sequence = self.get_sequence_data(sequence)
+
+        if not sequence:
+            return None
+        
+        return gazu.shot.all_shots_for_sequence(sequence)
     
     def get_shots(self, task_status_filters=None):
         if task_status_filters is not None:
@@ -187,6 +196,11 @@ class KitsuAPIWrapper(flow.Object):
             self._config.project_id.get(),
             name
         )
+
+    def get_sequences_data(self):
+        return gazu.shot.all_sequences_for_project(
+            self._config.project_id.get()
+        )
     
     def get_sequence_casting(self, sequence):
         if isinstance(sequence, str):
@@ -202,6 +216,18 @@ class KitsuAPIWrapper(flow.Object):
             self._config.project_id.get(),
             name
         )
+
+    def get_assets_data(self, asset_type):
+        if isinstance(asset_type, str):
+            asset_type = self.get_asset_type_data(asset_type)
+
+        if not asset_type:
+            return None
+        
+        return gazu.asset.all_assets_for_project_and_type(
+            self._config.project_id.get(),
+            asset_type
+        )
     
     def get_asset_type(self, asset):
         if isinstance(asset, str):
@@ -211,6 +237,24 @@ class KitsuAPIWrapper(flow.Object):
             return None
 
         return gazu.asset.get_asset_type(asset["entity_type_id"])
+
+    def get_asset_type_data(self, name):
+        return gazu.asset.get_asset_type_by_name(
+            name
+        )
+
+    def get_asset_types_data(self):
+        import requests
+        try:
+            data = gazu.project.get_project_by_name(
+                self._config.project_name.get()
+            )
+        except requests.exceptions.ConnectionError:
+            return None
+        else:
+            return gazu.asset.all_asset_types_for_project(
+                data
+            )
     
     def get_task(self, entity, task_type_name):
         task_type = gazu.task.get_task_type_by_name(task_type_name)
@@ -295,6 +339,16 @@ class KitsuAPIWrapper(flow.Object):
             kitsu_user = gazu.person.get_person_by_email(user_kitsu_id)
         
         return kitsu_user
+
+    def get_users(self):
+        data = gazu.project.get_project(
+            self.get_project_id()
+        )
+        user_names = []
+        for user_id in data['team']:
+            user_dict = gazu.person.get_person(user_id)
+            user_names.append(user_dict['desktop_login'])
+        return sorted(user_names)
     
     def user_is_assigned(self, kitsu_user, kitsu_task):
         kitsu_id = kitsu_user.get('id', None)
