@@ -183,6 +183,14 @@ class CreateTaskDefaultFiles(flow.Action):
 # -------------------------
 
 
+class FileTypeValue(flow.values.SessionValue):
+
+    DEFAULT_PATH_FORMAT = 'choice'
+
+    def choices(self):
+        return ['INPUT', 'OUTPUT', 'WORK']
+
+
 class PathFormatValue(flow.values.SessionValue):
 
     def revert_to_default(self):
@@ -204,6 +212,7 @@ class CreateDefaultFileAction(flow.Action):
     file_name   = flow.SessionParam('').ui(
         placeholder='layout.blend'
     )
+    file_type   = flow.SessionParam('WORK', FileTypeValue)
     path_format = flow.SessionParam(DEFAULT_PATH_FORMAT, PathFormatValue).ui(
         placeholder='{film}/{shot}/{file}/{revision}'
     )
@@ -262,6 +271,7 @@ class DefaultFile(flow.Object):
     """
 
     file_name   = flow.Param()
+    file_type   = flow.Param()
     path_format = flow.Param()
     enabled     = flow.BoolParam(False)
     optional    = flow.BoolParam(False)
@@ -650,6 +660,8 @@ class DefaultTask(flow.Object):
     color        = flow.Param(None, EditableTaskColor)
     icon         = flow.Param()
     files        = flow.Child(DefaultTaskFiles).ui(expanded=True)
+    default_edit_file = flow.Param()
+    priority_actions  = flow.Param()
 
     subtasks     = flow.OrderedStringSetParam()
 
@@ -658,7 +670,7 @@ class DefaultTask(flow.Object):
     def get_color(self):
         color = self.color.get()
 
-        if color is None:
+        if not color:
             mgr = self.root().project().get_task_manager()
             tp = mgr.task_templates[self.template.get()]
             color = tp.color.get()
@@ -668,7 +680,7 @@ class DefaultTask(flow.Object):
     def get_icon(self):
         icon = self.icon.get()
 
-        if icon is None:
+        if not icon:
             mgr = self.root().project().get_task_manager()
             tp = mgr.task_templates[self.template.get()]
             icon = tp.icon.get()
